@@ -1,23 +1,159 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 ## no critic ( NamingConventions::Capitalization )
 package Dist::Zilla::Plugin::Bootstrap::lib;
-BEGIN {
-  $Dist::Zilla::Plugin::Bootstrap::lib::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Dist::Zilla::Plugin::Bootstrap::lib::VERSION = '0.04000002';
-}
 ## use critic;
-
+$Dist::Zilla::Plugin::Bootstrap::lib::VERSION = '1.000000';
 # ABSTRACT: A minimal boot-strapping for Dist::Zilla Plug-ins.
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 
 
 
-use Moose;
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+use Moose qw( with );
 with 'Dist::Zilla::Role::Bootstrap';
 
 sub bootstrap {
@@ -61,7 +197,7 @@ Dist::Zilla::Plugin::Bootstrap::lib - A minimal boot-strapping for Dist::Zilla P
 
 =head1 VERSION
 
-version 0.04000002
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -113,8 +249,9 @@ Will do what you want.
 
 =head2 2-step self-dependency
 
-There's a 3rd useful case which is a hybrid of the 2, where you /can/ build from your own sources without needing a pre-installed version,
-just you don't want that for release code ( e.g.: $VERSION being C<undef> in code that is run during release is "bad" )
+There's a 3rd useful case which is a hybrid of the 2, where you /can/ build from your own sources without needing a
+pre-installed version, just you don't want that for release code ( e.g.: $VERSION being C<undef> in code that is run during
+release is "bad" )
 
     [Bootstrap::lib]
     try_built = 1
@@ -151,15 +288,16 @@ If this is a problem for you, then its suggested you try either variation of usi
 
 The core mechanism behind C<try_built> relies on looking in your project directory for a previous build directory of some kind.
 
-And there's no way for it to presently pick a "best" version when there are more than one, or magically provide a better solution
-if there are "zero" versions readily available.
+And there's no way for it to presently pick a "best" version when there are more than one, or magically provide a better
+solution if there are "zero" versions readily available.
 
-This is mostly because there is no way to determine the "current" version we are building for, because the point in the execution
-cycle is so early, no version plugins are likely to be even instantiated yet, and some version plugins are dependent on incredibly
-complex precursors ( like git ), so by even trying to garner the version we're currently building, we could be prematurely cutting off
-a vast majority of modules from even being able to bootstrap.
+This is mostly because there is no way to determine the "current" version we are building for, because the point in the
+execution cycle is so early, no version plugins are likely to be even instantiated yet, and some version plugins are dependent on
+incredibly complex precursors ( like git ), so by even trying to garner the version we're currently building, we could be
+prematurely cutting off a vast majority of modules from even being able to bootstrap.
 
-Even as it is, us using C<< zilla->name >> means that if your dist relies on some process to divine its name, the module that does this must
+Even as it is, us using C<< zilla->name >> means that if your dist relies on some process to divine its name, the module that
+does this must:
 
 =over 4
 
@@ -169,13 +307,17 @@ Even as it is, us using C<< zilla->name >> means that if your dist relies on som
 
 =back
 
-The only way of working around that I can envision is adding parameters to C<Bootstrap::lib> to specify the dist name and version name... but if you're going to do that, you may as well stop using external plugins to discover that, and hard-code those values in C<dist.ini> to start with.
+The only way of working around that I can envision is adding parameters to C<Bootstrap::lib> to specify the dist name and version
+name... but if you're going to do that, you may as well stop using external plugins to discover that, and hard-code those values
+in C<dist.ini> to start with.
 
 =head2 STILL NOT REALLY A PLUGIN
 
-Starting at version 0.04000000 ( read: 0.04_0000_00 aka 0.04 + 0 x 4 + 0 x 2 ) this module is a fully fledged class, different only from
-standard Dist::Zilla Plugins in that it doesn't partake in normal phase order, and only executes during a special custom C<::Bootstrap> phase,
-which is more or less a different name and implementation of C<BUILD>, in that C<bootstrap> is invoked after C<plugin_from_config> is called ( where C<new> is called ), which occurs somewhere in the middle of C<register_component>
+Starting at version 0.04000000 ( read: 0.04_0000_00 aka 0.04 + 0 x 4 + 0 x 2 ) this module is a fully fledged class, different
+only from standard Dist::Zilla Plugins in that it doesn't partake in normal phase order, and only executes during a special
+custom C<::Bootstrap> phase, which is more or less a different name and implementation of C<BUILD>, in that C<bootstrap> is
+invoked after C<plugin_from_config> is called ( where C<new> is called ), which occurs somewhere in the middle of
+C<register_component>
 
 This module also appears on the plugin stash, and responds naturally to C<metaconfig> requests.
 
@@ -196,7 +338,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
